==> tencentcloud-sdk-java-3.1.86-sources.jar: com/tencentcloudapi/ocr/v20181119/models/InsuranceBillOCRResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ocr.v20181119.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class InsuranceBillOCRResponse extends AbstractModel{

    /**
    * 保险单据识别结果，具体内容请点击左侧链接。
    */
    @SerializedName("InsuranceBillInfos")
    @Expose
    private InsuranceBillInfo [] InsuranceBillInfos;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 保险单据识别结果，具体内容请点击左侧链接。 
     * @return InsuranceBillInfos 保险单据识别结果，具体内容请点击左侧链接。
     */
    public InsuranceBillInfo [] getInsuranceBillInfos() {
        return this.InsuranceBillInfos;
    }

    /**
     * Set 保险单据识别结果，具体内容请点击左侧链接。
     * @param InsuranceBillInfos 保险单据识别结果，具体内容请点击左侧链接。
     */
    public void setInsuranceBillInfos(InsuranceBillInfo [] InsuranceBillInfos) {
        this.InsuranceBillInfos = InsuranceBillInfos;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "InsuranceBillInfos.", this.InsuranceBillInfos);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.920-sources.jar: com/tencentcloudapi/ocr/v20181119/models/InsuranceBillOCRResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ocr.v20181119.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class InsuranceBillOCRResponse extends AbstractModel {

    /**
    * 保险单据识别结果，具体内容请点击左侧链接。
    */
    @SerializedName("InsuranceBillInfos")
    @Expose
    private InsuranceBillInfo [] InsuranceBillInfos;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 保险单据识别结果，具体内容请点击左侧链接。 
     * @return InsuranceBillInfos 保险单据识别结果，具体内容请点击左侧链接。
     */
    public InsuranceBillInfo [] getInsuranceBillInfos() {
        return this.InsuranceBillInfos;
    }

    /**
     * Set 保险单据识别结果，具体内容请点击左侧链接。
     * @param InsuranceBillInfos 保险单据识别结果，具体内容请点击左侧链接。
     */
    public void setInsuranceBillInfos(InsuranceBillInfo [] InsuranceBillInfos) {
        this.InsuranceBillInfos = InsuranceBillInfos;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public InsuranceBillOCRResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public InsuranceBillOCRResponse(InsuranceBillOCRResponse source) {
        if (source.InsuranceBillInfos != null) {
            this.InsuranceBillInfos = new InsuranceBillInfo[source.InsuranceBillInfos.length];
            for (int i = 0; i < source.InsuranceBillInfos.length; i++) {
                this.InsuranceBillInfos[i] = new InsuranceBillInfo(source.InsuranceBillInfos[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "InsuranceBillInfos.", this.InsuranceBillInfos);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
